# Superwise.ai Python SDK

### A python SDK to integrate with superwise.ai

In order to use this library you need:

```
python > 3.0
```

### Install

use pip to install superwise SDK

```
pip install superwise

```

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags).


For getting started, HOWTOs, jupyter notebooks examples etc, use Superwise documentation portal:  https://docs.superwise.ai/


## License
The Superwise.ai SDK released under MIT licence (See LICENSE file)
